==> UPS-courier_v1.4.3.zip: UPS-courier v1.4.3/UPS-courier v1.4.3.oxp/Scripts/pirate_upsbase.js <==
this.name      = "pirate_upsbase"; 
this.author    = "eric walch"; 
this.copyright = " 2008 eric walch."; 
this.version   = "1.01";

this.shipSpawned = function()
{
    this.ReserveEnergy = this.ship.maxEnergy * missionVariables.ups_c2count * 0.25
    // make ship 25% stronger on every kill.
    delete this.shipSpawned;
}

this.shipDied = function() 
{ 
    if(missionVariables.ups_container == "SEARCHING3" || missionVariables.ups_container == "JOINED_PIRATES" || missionVariables.ups_container == "JOINED_PIRATES2") missionVariables.ups_container = "FOUND3"
    if(missionVariables.ups_container == "SEARCHING4") missionVariables.ups_container = "FOUND4"
    missionVariables.TL_FOR_EQ_UPS_POLICE_SCANNER = null
    missionVariables.TL_FOR_EQ_UPS_IDCLEANER = null
    player.commsMessage("Next time we will have an even stronger base!", 6)
    if (missionVariables.ups_cloaking == "CRIPPLED") 
    { 
        worldScripts["ups_container"].playerShip.removeEquipment("EQ_CRIPPLED_CLOAKING")
	worldScripts["ups_container"].playerShip.awardEquipment("EQ_CLOAKING_DEVICE")
	missionVariables.ups_cloaking = null
	player.consoleMessage("Cloaking ability restored", 4);
    }
    mission.setInstructionsKey("ups_containers_small4b", "ups_container")
    mission.unmarkSystem(missionVariables.ups_cplanet)

    delete this.shipDied;
}

this.shipBeingAttacked = function()
{
    if(this.ship.energy < this.ship.maxEnergy * 0.5 && this.ReserveEnergy > 0)
    {
        if (this.ReserveEnergy > 500)
        {
            this.ReserveEnergy -= 500
            this.ship.energy += 500
            player.commsMessage("You can shoot now, but we win at the end.", 6)
        }
        else
        {
            this.ship.energy += this.ReserveEnergy
            this.ReserveEnergy = 0
        }
    }
}

==> UPS-courier_v1.4.4.zip: UPS-courier v1.4.4/UPS-courier v1.4.4.oxp/Scripts/pirate_upsbase.js <==
this.name      = "pirate_upsbase"; 
this.author    = "eric walch"; 
this.copyright = " 2008 eric walch."; 
this.version   = "1.01";

this.shipSpawned = function()
{
    this.ReserveEnergy = this.ship.maxEnergy * missionVariables.ups_c2count * 0.25
    // make ship 25% stronger on every kill.
    delete this.shipSpawned;
}

this.shipDied = function() 
{ 
    if(missionVariables.ups_container == "SEARCHING3" || missionVariables.ups_container == "JOINED_PIRATES" || missionVariables.ups_container == "JOINED_PIRATES2") missionVariables.ups_container = "FOUND3"
    if(missionVariables.ups_container == "SEARCHING4") missionVariables.ups_container = "FOUND4"
    missionVariables.TL_FOR_EQ_UPS_POLICE_SCANNER = null
    missionVariables.TL_FOR_EQ_UPS_IDCLEANER = null
    this.ship.commsMessage("Next time we will have an even stronger base!")
    if (missionVariables.ups_cloaking == "CRIPPLED") 
    { 
        player.ship.removeEquipment("EQ_CRIPPLED_CLOAKING")
	player.ship.awardEquipment("EQ_CLOAKING_DEVICE")
	missionVariables.ups_cloaking = null
	player.consoleMessage("Cloaking ability restored", 4);
    }
    mission.setInstructionsKey("ups_containers_small4b", "ups_container")
    mission.unmarkSystem(missionVariables.ups_cplanet)

    delete this.shipDied;
}

this.shipBeingAttacked = function()
{
    if(this.ship.energy < this.ship.maxEnergy * 0.5 && this.ReserveEnergy > 0)
    {
        if (this.ReserveEnergy > 500)
        {
            this.ReserveEnergy -= 500
            this.ship.energy += 500
            this.ship.commsMessage("You can shoot now, but we win at the end.")
        }
        else
        {
            this.ship.energy += this.ReserveEnergy
            this.ReserveEnergy = 0
        }
    }
}
